"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Sets up tables in a PostgreSQL database.
 * @param knex Knex instance to use to setup tables.
 * @param options Specifies table names and other options
 */
function setupTables(knex, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const newOptions = Object.assign({
            tableName: 'postqueue',
            resultTableName: 'postqueue_results'
        }, options);
        yield knex.schema.createTable(newOptions.tableName, tbl => {
            tbl.increments('id');
            tbl.json('input_data');
            tbl.string('queue_name').notNullable();
            tbl.integer('every_secs');
            tbl.dateTime('last_run');
            tbl.boolean('delete_on_acknowledged').notNullable();
        });
        yield knex.schema.createTable(newOptions.resultTableName, tbl => {
            tbl.increments('id');
            tbl.integer('job_id').notNullable().unsigned();
            tbl.json('result');
            tbl.dateTime('time_run');
        });
    });
}
exports.setupTables = setupTables;
/**
 * Drops tables from PostgreSQL database.
 * @param knex Knex instance to use to drop tables
 * @param options Specifies table names
 */
function dropTables(knex, options) {
    return __awaiter(this, void 0, void 0, function* () {
        const newOptions = Object.assign({
            tableName: 'postqueue',
            resultTableName: 'postqueue_results'
        }, options);
        yield knex.schema.dropTable(newOptions.resultTableName);
        yield knex.schema.dropTable(newOptions.tableName);
    });
}
exports.dropTables = dropTables;
