import * as Knex from 'knex';
import { TableOptions } from './migrations';
interface JobOptions {
    deleteOnAcknowledged?: boolean;
    everySecs?: number;
}
/**
 * Represents a single or recurring job by ID.
 */
export declare class Job {
    id: number;
    private knex;
    private tx?;
    private tableOptions;
    private pollMs;
    data: any;
    constructor(id: number, knex: Knex, tableOptions: TableOptions, pollMs: number, tx?: Knex.Transaction);
    /**
     * Waits for a job to complete (only applicable to non-recurring jobs)
     */
    done(): Promise<any>;
    /**
     * Removes job from queue
     */
    remove(): Promise<void>;
}
export interface QueueOptions extends TableOptions {
    pollInterval: number;
}
/**
 * This represents a single queue.
 */
export declare class Queue {
    name: string;
    knex: Knex;
    tableOptions: TableOptions;
    pollInterval: number;
    shouldProcess: boolean;
    constructor(name: string, knex: Knex, options?: Partial<QueueOptions>);
    /**
     * Adds a single or recurring job to the queue
     * @param data Job data
     * @param options Job options
     */
    add(data: any, options?: JobOptions): Promise<Job>;
    /**
     * Gets a Job object from the queue.
     * @param id Job ID number
     */
    getJob(id: number): Job;
    /**
     * Process runs the queue and processes jobs.
     * @param cb Callback to handle a job. Return value should be job result.
     */
    process(cb: (j: Job) => Promise<any>): void;
    shutdown(): void;
}
export {};
