"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const queue_1 = require("./queue");
const chai_1 = require("chai");
const knex_1 = __importDefault(require("knex"));
require("mocha");
const migrations_1 = require("./migrations");
const db = knex_1.default({
    client: 'postgresql',
    connection: {
        database: 'postqueue_test' || process.env.POSTGRES_DB,
        user: 'postgres' || process.env.POSTRGES_USER,
        password: '' || process.env.POSTGRES_PASS
    }
});
describe('queue', () => {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        const tablesExist = yield db.schema.hasTable('postqueue');
        if (!tablesExist) {
            yield migrations_1.setupTables(db);
        }
    }));
    it('should successfully add and delete', () => __awaiter(void 0, void 0, void 0, function* () {
        const q = new queue_1.Queue('test-queue', db);
        const job = yield q.add({
            test: 'hello-world'
        });
        yield job.remove();
    }));
    it('should process jobs', (done) => {
        (() => __awaiter(void 0, void 0, void 0, function* () {
            const q = new queue_1.Queue('test-queue', db);
            yield q.add({
                test: 'hello-world'
            });
            q.process((j) => __awaiter(void 0, void 0, void 0, function* () {
                chai_1.expect(j.data).to.not.be.equal(null);
                chai_1.expect(j.data.test).to.be.equal('hello-world');
                q.shutdown();
                yield j.remove();
                done();
                return null;
            }));
        }))();
    });
    it('should process recurring jobs multiple times', (done) => {
        (() => __awaiter(void 0, void 0, void 0, function* () {
            const q = new queue_1.Queue('test-queue', db);
            let triggered = 0;
            const job = yield q.add({
                test: 'hello-world'
            }, {
                everySecs: 1
            });
            q.process((j) => __awaiter(void 0, void 0, void 0, function* () {
                chai_1.expect(j.data).to.not.be.equal(null);
                chai_1.expect(j.data.test).to.be.equal('hello-world');
                triggered++;
                if (triggered === 2) {
                    q.shutdown();
                    yield j.remove();
                    done();
                }
                return null;
            }));
        }))();
    }).timeout(5000);
    after(() => {
        setImmediate(() => {
            db.destroy();
        });
    });
});
